-- moonlight Theme Preferences Handler

--[[
scratchpad
* use profile names as extensions, providing by-profile options?
]]

--[[ theme colors ]]
-- limited choices version:
ThemeColors = {
	Yellow  = "#FFFFFB",	-- a: yellow (default/classic)
	Purple  = "#FFFBFF",	-- b: purple
	Cyan    = "#FBFFFF",	-- c: cyan
	Red     = "#FFFBFB",	-- d: red
	Green   = "#FBFFFB",	-- e: green
	Blue    = "#FBFBFF",	-- f: blue
	Special = "#EBFAFF"		-- special color!
};

function GetThemeColor()
	if GetUserPref("ThemeColor") then
		return GetUserPrefC("ThemeColor");
	else
		SetUserPref("ThemeColor",ThemeColors['Yellow']);
		return color(ThemeColors['Yellow']);
	end;
end;
--[[ end theme colors ]]

--[[ preference helpers ]]
--[[ end preference helpers ]]

--[[ option rows ]]
function OptionRowSongTitleDisplay()
	local t = {
		-- Name is used to retrieve the header and explanation text.
		Name = "Song/Course Title Display";
		LayoutType = "ShowAllInRow";
		SelectType = "SelectOne";
		OneChoiceForAllPlayers = true;
		ExportOnChange = false;
		Choices = { 'On','Off' };
		LoadSelections = function(self, list, pn)
			list[1] = true;
		end;
		SaveSelections = function(self, list, pn)
			local val;
			if list[2] then
				val = false;
			else
				val = true;
			end
			SetUserPref("GameplayTitle",val);
		end;
	};
	setmetatable( t, t );
	return t;
end;

function OptionRowPlayerOptionsDisplay()
	local t = {
		Name = "Player Options Display";
		LayoutType = "ShowAllInRow";
		SelectType = "SelectOne";
		OneChoiceForAllPlayers = true;
		ExportOnChange = false;
		Choices = { 'On','Off' };
		LoadSelections = function(self, list, pn)
			list[1] = true;
		end;
		SaveSelections = function(self, list, pn)
			local val;
			if list[2] then
				val = false;
			else
				val = true;
			end
			SetUserPref("DisplayModsOption",val);
		end;
	};
	setmetatable( t, t );
	return t;
end;

-- screen filter
function OptionRowPlayerFilter()
	local t = {
		Name = "Screen Filter";
		LayoutType = "ShowAllInRow";
		SelectType = "SelectOne";
		OneChoiceForAllPlayers = false;
		ExportOnChange = false;
		Choices = { 'Off','On' };
		LoadSelections = function(self, list, pn)
			local pname = pname(pn);
			
			if getenv("ScreenFilter"..pname) == true then
				list[2] = true;
			else
				list[1] = true;
			end;
		end;
		SaveSelections = function(self, list, pn)
			local val;
			if list[2] then
				val = true;
			else
				val = false;
			end;
			local pname = pname(pn);
			setenv("ScreenFilter"..pname, val);
		end;
	};
	setmetatable( t, t );
	return t;
end;

-- screen cover
function OptionRowPlayerCover()
	local t = {
		Name = "Screen Cover";
		LayoutType = "ShowAllInRow";
		SelectType = "SelectOne";
		OneChoiceForAllPlayers = false;
		ExportOnChange = false;
		Choices = { 'Off','On' };
		LoadSelections = function(self, list, pn)
			local pname = pname(pn);
			
			if getenv("ScreenCover"..pname) == true then
				list[2] = true;
			else
				list[1] = true;
			end;
		end;
		SaveSelections = function(self, list, pn)
			local val;
			if list[2] then
				val = true;
			else
				val = false;
			end;
			local pname = pname(pn);
			setenv("ScreenCover"..pname, val);
		end;
	};
	setmetatable( t, t );
	return t;
end;

function OptionRowDPMeterDisplay()
	local t = {
		-- Name is used to retrieve the header and explanation text.
		Name = "Dance Point Meter Display";
		LayoutType = "ShowAllInRow";
		SelectType = "SelectOne";
		OneChoiceForAllPlayers = true;
		ExportOnChange = false;
		Choices = { 'On','Off' };
		LoadSelections = function(self, list, pn)
			local pname = pname(pn);
			
			if GetUserPref("DPMeter") == "false" then
				list[2] = true;
			else
				list[1] = true;
			end;
		end;
		SaveSelections = function(self, list, pn)
			local val;
			if list[2] then
				val = false;
			else
				val = true;
			end
			SetUserPref("DPMeter",val);
		end;
	};
	setmetatable( t, t );
	return t;
end;

function OptionRowBPMDisplay()
	local t = {
		-- Name is used to retrieve the header and explanation text.
		Name = "BPM Display";
		LayoutType = "ShowAllInRow";
		SelectType = "SelectOne";
		OneChoiceForAllPlayers = true;
		ExportOnChange = false;
		Choices = { 'On','Off' };
		LoadSelections = function(self, list, pn)
			local pname = pname(pn);
			
			if GetUserPref("SongBPMDisplay") == "false" then
				list[2] = true;
			else
				list[1] = true;
			end;
		end;
		SaveSelections = function(self, list, pn)
			local val;
			if list[2] then
				val = false;
			else
				val = true;
			end
			SetUserPref("SongBPMDisplay",val);
		end;
	};
	setmetatable( t, t );
	return t;
end;
--[[ end option rows ]]